# 基础服务


## NATS

```bash
docker run -d --name nats -p 4222:4222 -p 6222:6222 -p 8222:8222 nats -m 5000
```

# mysql

```bash
docker run --name mysql -e MYSQL_ROOT_PASSWORD=root -d mysql:5.7
```

## nacos

`http://<your-docker-host-ip>:8848/nacos` 来访问Nacos控制台。默认的用户名和密码都是 `nacos`

```bash
# 单节点模式
docker run -d -p 8848:8848 -e MODE=standalone nacos/nacos-server --name nacos
```

## redis

```
docker run --name redis -d -p 6379:6379 -e TZ=Asia/Shanghai redis:alpine --requirepass redis
```

## 普罗米修斯

```
docker run -p 9090:9090 -v /path/to/prometheus.yml:/etc/prometheus/prometheus.yml prom/prometheus
```


## nestjs 相关


providers 是一个数组，用于列出此模块中提供的服务。这些服务可以被该模块中的其他部分（例如控制器和其他服务）通过依赖注入（Dependency Injection）进行使用。一旦你将一个类列为模块的provider，NestJS就会负责在需要时创建和销毁这个类的实例。

imports 是一个数组，用于列出此模块依赖的其他模块。通过这种方式，一个模块可以访问另一个模块中的providers。简单来说，如果你想要在一个模块的服务中使用另一个模块的服务，你就需要将那个模块添加到imports数组中。

exports 是一个数组，用于列出此模块想要公开的providers，使得其他模块可以访问这些providers。如果你想让一个模块的服务可以被其他模块使用，你就需要将那个服务添加到exports数组中。

```ts
import { Module } from '@nestjs/common';
import { CatsController } from './cats.controller';
import { CatsService } from './cats.service';
import { DatabaseModule } from '../database/database.module';

@Module({
  imports: [DatabaseModule],  // 此模块依赖DatabaseModule
  controllers: [CatsController],
  providers: [CatsService],  // 在此模块中定义CatsService
  exports: [CatsService],  // 允许其他模块访问CatsService
})
export class CatsModule {}
```

# ohifv3

```bash
# docker run -d -p 3000:80/tcp --name LatestReleasedOHIF ohif/app:latest
docker run -d -p 3000:80/tcp -v /Users/mozzie/Desktop/tavi-universe/ohifv3/app-config.js:/usr/share/nginx/html/app-config.js -v /Users/mozzie/Desktop/tavi-universe/ohifv3/conf.d:/etc/nginx/conf.d --name ohifv3 ohif/app:latest
```



## Minio

```bash
docker run -d --restart=always \
  -p 19000:9000 -p 19001:9001 \
  --name minio1 \
  -v /Users/mozzie/minio:/data \
  -e "MINIO_ROOT_USER=minio" \
  -e "MINIO_ROOT_PASSWORD=12345678" \
  minio/minio server /data --console-address ":9001"
```