import { makeAutoObservable } from "mobx";
import { UserLoginForm } from "./entities/UserLoginForm";
import { FormFields } from "@/modules/Login/LoginForm";
import { UserRepository } from "./UserRepository";
import { User } from "./entities/User";

export class UserService {
  user: User;
  loginForm: UserLoginForm;

  constructor(private userRepository: UserRepository) {
    this.user = new User();
    this.loginForm = new UserLoginForm();
    makeAutoObservable(this);
  }

  /**
   * update User领域models中的loginForm对象
   */
  updateLoginForm(values: FormFields) {
    this.loginForm = values;
  }

  /**
   * 登录事件
   */
  async handleLogin(values: FormFields) {
    const { username, password } = values;
    const { code, msg, data } = await this.userRepository.authLogin({
      username,
      password,
    });
    return { success: code === "ok", code, msg };
  }

  /**
   * 获取用户信息
   */
  async userAuth() {
    const { code, data, msg } = await this.userRepository.userAuth();
    if (code === 0 && data?.tokenValid) {
      this.user.signIn();
      return { success: true, data };
    } else {
      this.user.signOut();
      return { success: false, msg };
    }
  }
}
