import { AiOutlineGlobal } from "react-icons/ai";
import { i18n } from "@/App";
import { ConfigProvider, Select } from "antd";
import { useEffect, useState } from "react";
import { defaultLang } from "@/constant";

interface LanguageSelectProps {
  children?: JSX.Element;
}

const langOptions = [
  { value: "zh-CN", label: "中文(Chinese)" },
  { value: "en-US", label: "English" },
];

export const LanguageSelect = (props: LanguageSelectProps) => {
  const [language, setLanguage] = useState<string>();

  useEffect(() => setLanguage(i18n?.language ?? defaultLang), []);

  const onLanguageChange = (v: string) => {
    i18n.changeLanguage(v);
    setLanguage(v);
  };

  return (
    <ConfigProvider
      theme={{
        token: {
          colorPrimary: "#585963",
          colorBorder: "#585963",
          colorBgBase: "transparent",
          colorTextBase: "#fff",
        },
      }}
    >
      <div style={{ display: "flex", alignItems: "center" }}>
        <AiOutlineGlobal
          style={{
            fontSize: "1.71rem",
            color: "#585963",
            marginRight: ".25rem",
          }}
        />
        <Select
          size="small"
          value={language}
          onChange={onLanguageChange}
          options={langOptions}
        />
      </div>
    </ConfigProvider>
  );
};
