import { createContext, useEffect, useState } from "react";
import { useNavigate } from "react-router";

type Auth = {
  isLoggedIn: boolean;
};

type AuthContextType = {
  auth: Auth;
  setAuth: React.Dispatch<React.SetStateAction<Auth>>;
};

const defaultAuth: AuthContextType["auth"] = { isLoggedIn: false };
const defaultSetAuth: AuthContextType["setAuth"] = () => {};

export const AuthContext = createContext<AuthContextType>({
  auth: defaultAuth,
  setAuth: defaultSetAuth,
});

interface AuthProviderProps {
  children?: JSX.Element;
}

export const AuthProvider = (props: AuthProviderProps) => {
  const [auth, setAuth] = useState<Auth>({ isLoggedIn: false });

  return (
    <AuthContext.Provider value={{ auth, setAuth }}>
      {props.children}
    </AuthContext.Provider>
  );
};
