import { LanguageSelect } from "@/components/LanguageSelect";
import { Logo } from "@/components/Logo";
import { FormFields, LoginForm } from "./LoginForm";
import "./index.less";
import { useDomain } from "@/hook/useDomain";
import { useTranslation } from "@tavi/i18n";
import { Observer, observer } from "mobx-react-lite";
import { UserService } from "@@/domain/User/UserService";
import { useNavigate } from "react-router";
import { message } from "antd";

interface LoginProps {
  children?: JSX.Element;
}

// const TestComponent: React.FC<{ domainService: UserService }> = observer(
//   ({ domainService }) => (
//     <div style={{ color: "#fff" }}>
//       <p>name: {domainService.user.isLoggedIn ? "登录" : "未登录"}</p>
//     </div>
//   )
// );

export const Login = (props: LoginProps) => {
  const { t } = useTranslation();
  const navigate = useNavigate();
  const [messageApi, contextHolder] = message.useMessage();
  const { userDomainService } = useDomain();

  /**
   * 登录
   */
  const onLogin = async (v: FormFields) => {
    const { success, msg } = await userDomainService.handleLogin(v);
    if (success) {
      messageApi.success(msg);
      navigate("/");
    } else {
      messageApi.error(msg);
    }
  };

  return (
    <div
      className="login-wrapper"
      style={{ backgroundImage: `url('/img/login_mask.webp')` }}
    >
      <div
        className="illustration"
        style={{ backgroundImage: `url('/img/login_1.webp')` }}
      >
        <aside>
          {contextHolder}
          <header>
            <Logo isClicked={false} />
            <LanguageSelect />
          </header>
          {/* <TestComponent domainService={userDomainService} /> */}
          <LoginForm
            styles={{ width: "100%" }}
            onFormChange={(v) => userDomainService.updateLoginForm(v)}
            onLogin={onLogin}
          />
          <footer style={{ paddingTop: "6.64rem", color: "#585963" }}>
            <span className="forget-pass">{t("LOGIN.FORGET_PASS")}</span>
          </footer>
        </aside>
      </div>
    </div>
  );
};
