import { useEffect, useRef, useState } from "react";
import "./index.less";
import axios from "axios";

interface ImageItemProps {
  children?: JSX.Element;
  src?: string;
  imgStyle?: React.CSSProperties;
  title?: string;
}

export const ImageItem = (props: ImageItemProps) => {
  const [actionVisible, setActionVisible] = useState(false);
  const imgRef = useRef<HTMLImageElement | null>(null);
  const actionRef = useRef<HTMLElement | null>(null);
  const fileInputRef = useRef<HTMLInputElement | null>(null);
  const [imgSrc, setImgSrc] = useState(props.src);

  useEffect(() => {
    const handleClickOutside = (e: any) => {
      if (actionRef.current?.contains(e.target)) return e.preventDefault();
      if (imgRef.current && !imgRef.current.contains(e.target))
        setActionVisible(false);
    };
    document.addEventListener("mousedown", handleClickOutside);
    return () => document.addEventListener("mousedown", handleClickOutside);
  }, [imgRef]);

  /**
   * 删除图片
   */
  const onDelete = () => {
    setImgSrc("");
    fileInputRef.current?.setAttribute("value", "");
  };
  3;
  const onInsert = () => fileInputRef.current?.click();

  const handleFileChange = (event: any) => {
    if (event.target.files && event.target.files[0]) {
      const fd = new FormData();
      fd.append("file", event.target.files[0]);
      axios
        .post("/api/report/upload", fd, {
          headers: { "Content-Type": "multipart/form-data" },
        })
        .then((res) => {
          const { objectName } = res.data;
          setImgSrc(`/api/report/img/${objectName}`);
        });
      //TODO API接口上传，THEN
      setImgSrc(event.target.result);
    }
  };

  return (
    <div className="image-card">
      <p>{props.title}</p>
      {!imgSrc ? (
        <div></div>
      ) : (
        <div
          onClick={() => setActionVisible(true)}
          className={`img ${actionVisible ? "active" : ""}`}
          ref={imgRef}
          style={{ ...props.imgStyle, backgroundImage: `url(${imgSrc})` }}
        ></div>
      )}
      {actionVisible && (
        <section ref={actionRef}>
          <input
            type="file"
            accept="image/*" // 接受任何类型的图片文件
            ref={fileInputRef}
            onChange={handleFileChange}
            style={{ display: "none" }} // 隐藏真正的文件输入元素
          />
          {!!imgSrc && <button onClick={onDelete}>删除</button>}
          <button onClick={onInsert}>插入</button>
        </section>
      )}
    </div>
  );
};
