import './index.less'

export type TableDataCell = {
  prop: string
  content: string
  colSpan?: number
  highlight?: boolean
}

export type TableData = TableDataCell[][]

interface TableProps {
  children?: JSX.Element
  data: TableData
  style?: React.CSSProperties
  border?: { vertical?: boolean; horizon?: boolean; outer?: boolean }
}

export const Table = (props: TableProps) => {
  return (
    <table
      style={{ ...props.style }}
      className={`table-cell ${props.border?.outer ? 'border-outer' : ''}`}
    >
      <tbody>
        {props.data.map((row, rowIndex) => (
          <tr key={rowIndex}>
            {row.map((cell, cellIndex: number) => {
              if (typeof cell === 'object') {
                return (
                  <td
                    key={cellIndex}
                    className={[
                      props.border?.vertical && 'border-vertical',
                      props.border?.horizon && 'border-horizon'
                    ]
                      .filter(Boolean)
                      .join(' ')}
                    colSpan={cell.colSpan}
                  >
                    <span>{cell.prop}:</span>
                    <span
                      style={{ paddingLeft: '.7rem' }}
                      className={cell.highlight ? 'highlight' : ''}
                    >
                      {cell.content}
                    </span>
                  </td>
                )
              }
              return <td key={cellIndex}>{cell}</td>
            })}
          </tr>
        ))}
      </tbody>
    </table>
  )
}
