import { useEffect, useState } from "react";
import { Paper } from "./components/Paper";
import { Aorta } from "./pages/Aorta";
import { Catalogue } from "./pages/Catalogue";
import { PatientProfile } from "./pages/PatientProfile";
import { ProjectionAngle } from "./pages/ProjectionAngle";
import { dom2PDF } from "@tavi/util";
import { LVOT } from "./pages/LVOT";
import { SOV } from "./pages/SOV";
import { STJ } from "./pages/STJ";
import { AscAorta } from "./pages/AscAorta";
import { AortaValve } from "./pages/AortaValve";
import { Calcify } from "./pages/Calcify";
import { Slice } from "./pages/Slice";
import { RingShape } from "./pages/RingShape";
import { Coronary } from "./pages/Coronary";
import { RightCoronary } from "./pages/RightCoronary";
import { LeftCoronarySinus } from "./pages/LeftCoronarySinus";
import { RightCoronarySinus } from "./pages/RightCoronarySinus";
import { NoCoronarySinus } from "./pages/NoCoronarySinus";
import { ProjectionAngleP2 } from "./pages/ProjectionAngle-P2";
import { SuicideLeft } from "./pages/SuicideLeft";
import "./index.less";
import { ProgressBar } from "./components/ProgressBar";
import axios from "axios";

axios.defaults.withCredentials = true;

interface DoctorProps {
  children?: JSX.Element;
}

export const ReportFullVersion = (props: DoctorProps) => {
  const [date, totalPageNum] = ["2023-06-14", 21];
  const [completed, setCompleted] = useState(0);

  useEffect(() => {
    axios.get("/api/aorta/report/root").then((res) => {
      console.log(res);
    });
  }, []);

  /**
   * 下载pdf
   */
  const downloadHandler = () => {
    const elements = Array.from(
      document.querySelectorAll(".a4")
    ) as HTMLElement[];
    dom2PDF({
      elements,
      scale: 3,
      onProgress: (currentPage, totalPage) => {
        setCompleted(currentPage / totalPage);
      },
    }).then((pdf) => pdf.save("test.pdf"));
  };

  return (
    <div className="report-full-preview" style={{ padding: "24px 0" }}>
      {completed > 0 && (
        <ProgressBar
          completed={completed}
          bgColor="var(--color-primary)"
          color="var(--color-primary)"
        />
      )}
      <div className="action-bar">
        <button onClick={downloadHandler} className="download-pdf">
          下载
        </button>
      </div>
      <Paper date={date}>
        <PatientProfile />
      </Paper>
      <Paper date={date} pageNum={1} totalPageNum={totalPageNum}>
        <Catalogue />
      </Paper>
      <Paper date={date} pageNum={2} totalPageNum={totalPageNum}>
        <Aorta />
      </Paper>
      <Paper date={date} pageNum={3} totalPageNum={totalPageNum}>
        <LVOT />
      </Paper>
      <Paper date={date} pageNum={4} totalPageNum={totalPageNum}>
        <SOV />
      </Paper>
      <Paper date={date} pageNum={5} totalPageNum={totalPageNum}>
        <STJ />
      </Paper>
      <Paper date={date} pageNum={6} totalPageNum={totalPageNum}>
        <AscAorta />
      </Paper>
      <Paper date={date} pageNum={7} totalPageNum={totalPageNum}>
        <AortaValve />
      </Paper>
      <Paper date={date} pageNum={8} totalPageNum={totalPageNum}>
        <Calcify />
      </Paper>
      <Paper date={date} pageNum={9} totalPageNum={totalPageNum}>
        <Slice />
      </Paper>
      <Paper date={date} pageNum={10} totalPageNum={totalPageNum}>
        <RingShape />
      </Paper>
      <Paper date={date} pageNum={11} totalPageNum={totalPageNum}>
        <Coronary />
      </Paper>
      <Paper date={date} pageNum={12} totalPageNum={totalPageNum}>
        <RightCoronary />
      </Paper>
      <Paper date={date} pageNum={13} totalPageNum={totalPageNum}>
        <LeftCoronarySinus />
      </Paper>
      <Paper date={date} pageNum={14} totalPageNum={totalPageNum}>
        <RightCoronarySinus />
      </Paper>
      <Paper date={date} pageNum={15} totalPageNum={totalPageNum}>
        <NoCoronarySinus />
      </Paper>
      <Paper date={date} pageNum={16} totalPageNum={totalPageNum}>
        <ProjectionAngle />
      </Paper>
      <Paper date={date} pageNum={17} totalPageNum={totalPageNum}>
        <ProjectionAngleP2 />
      </Paper>
      <Paper date={date} pageNum={18} totalPageNum={totalPageNum}>
        <SuicideLeft />
      </Paper>
    </div>
  );
};
