import { Heading } from "../../components/Heading";
import "./index.less";
import { Section } from "./interface";

interface CatalogueProps {
  dataSource?: [];
}

const mockData: Section[] = [
  {
    title: "主动脉根部的大小和形态",
    subsections: [
      {
        title: "主动脉瓣环 Annulus",
        pageNumber: 2,
      },
      {
        title: "左室流出道 LVOT",
        pageNumber: 3,
      },
      {
        title: "瓦氏窦 SOV",
        pageNumber: 4,
      },
      {
        title: "窦管交界 STJ",
        pageNumber: 5,
      },
      {
        title: "升主动脉 Ascending Aorta",
        pageNumber: 6,
      },
    ],
  },
  {
    title: "主动脉瓣的形态和功能",
    subsections: [
      {
        title: "瓣叶类型",
        pageNumber: 7,
      },
      {
        title: "钙化形态",
        pageNumber: 8,
      },
      {
        title: "分割形态",
        pageNumber: 9,
      },
      {
        title: "环上形态",
        pageNumber: 10,
      },
    ],
  },
  {
    title: "冠状动脉和临近结构",
    subsections: [
      {
        title: "左冠开口高度",
        pageNumber: 11,
      },
      {
        title: "右冠开口高度",
        pageNumber: 12,
      },
      {
        title: "左冠窦瓣叶长度",
        forRef: true,
        pageNumber: 13,
      },
      {
        title: "右冠窦瓣叶长度",
        forRef: true,
        pageNumber: 14,
      },
      {
        title: "无冠窦瓣叶长度",
        forRef: true,
        pageNumber: 15,
      },
    ],
  },
  {
    title: "投照角度",
    subsections: [
      {
        title: "建议投照角度",
        pageNumber: 16,
      },
      {
        title: "三维重建效果",
        pageNumber: 17,
      },
    ],
  },
];

export const Catalogue = (props: CatalogueProps) => {
  return (
    <section className="catalogue">
      <Heading title="目录" level={1} />
      <ul>
        {mockData.map((section, i) => {
          return (
            <li key={i}>
              <header>
                <span>{i + 1}</span>
                <p>{section.title}</p>
              </header>
              <ol>
                {section.subsections?.map((sub, i_sub) => (
                  <li key={`${i}-${i_sub}`}>
                    <span>
                      {i + 1}-{i_sub + 1}
                    </span>
                    <div>
                      <span>
                        {sub.title}
                        {sub.forRef && <b>(仅供参考)</b>}
                      </span>
                      <div>
                        <em></em>
                      </div>
                    </div>
                    <span className="page-number">{sub.pageNumber}</span>
                  </li>
                ))}
              </ol>
            </li>
          );
        })}
      </ul>
    </section>
  );
};
