import { Heading } from "../../components/Heading";
import { Paragraph } from "../../components/Paragraph";
import { Reference } from "../../components/Reference";
import "./index.less";

interface PatientProfileProps {
  children?: JSX.Element;
}

const tableData = [
  {
    prop: "姓名",
    value: "刘伟",
  },
  {
    prop: "性别",
    value: "男",
  },
  {
    prop: "年龄",
    value: "68",
  },
  {
    prop: "医院",
    value: "阜外医院",
  },
  {
    prop: "报告日期",
    value: "2023-06-14",
  },
  {
    prop: "扫描日期",
    value: "2023-06-14",
  },
  {
    prop: "序列名称",
    value: "DS_CorCTA 0.75 I26f 3BestSyst 47 %",
    block: true,
  },
];

const guideData = [
  {
    title: "主动脉根部的大小和形态",
    content: "对冠状动脉解剖结构，以及TAVI和其他经导管手术的适用性进行评估诊断",
  },
  {
    title: "主动脉瓣的形态和功能",
    content:
      "对主动脉瓣膜、瓣叶、钙化，以及先天性畸形而导致瓣叶无法正常开启进行评估诊断",
  },
  {
    title: "冠状动脉和临近结构",
    content: "对TAVR手术后可能产生的并发症进行风险评估",
  },
  {
    title: "投照角度",
    content: "对主动脉根部进行三维模型重建，并对手术过程进行模拟",
  },
];

export const PatientProfile = (props: PatientProfileProps) => {
  return (
    <div className="patient-info">
      <Heading title="检测内容" />
      <Paragraph
        style={{ marginBottom: "2.86rem" }}
        text="CVPILOT是一款基于主动脉CT影像的心脏瓣膜疾病手术分析辅助决策系统。在术前全自动完成TAVR手术的结构标记、手术规划及风险判断，保障介入瓣膜的高精准植入。"
      />
      <Heading title="患者基本信息" />
      <div className="table" style={{ marginBottom: "2.86rem" }}>
        {tableData.map((item, i) => (
          <div
            key={i}
            className={["item", item.block && "full-width"]
              .filter(Boolean)
              .join(" ")}
          >
            <em>{item.prop}</em>
            <span>{item.value}</span>
          </div>
        ))}
      </div>
      <Heading title="指南分析" />
      <ul className="guide-list">
        {guideData.map((guide, i) => (
          <li key={i}>
            <h3>{guide.title}</h3>
            <p>{guide.content}</p>
          </li>
        ))}
      </ul>
      <Reference
        titleVisible
        style={{ position: "absolute", bottom: "3rem" }}
        literature={[
          "Catherine M. Otto, Rick A. Nishimura, Robert O. Bonow, Blase A. Carabello, John P. Erwin III,Federico Gentile, Hani Jneid, Eric V. Krieger, Michael Mack, Christopher McLeod, Patrick T. O’Gara, Vera H. Rigolin, Thoralf M. Sundt III, Annemarie Thompson, Christopher Toly. 2020 ACC/AHA Guideline for the Management of Patients With Valvular Heart Disease.Circulation. 2021;143:e35–e71. DOI: 10.1161/CIR.0000000000000932.",
        ]}
      />
    </div>
  );
};
