import { Apis } from "@@/infra/api";
import { Role } from "./entities/Role";
import { Permission } from "./entities/Permission";
import { User } from "./entities/User";

export class RbacRepository {
  async saveRole(role: Role) {
    const { code } = await Apis.saveRole(role);
    return code === "ok";
  }

  async updateRole(role: Role) {
    const { code } = await Apis.updateRole(role);
    return code === "ok";
  }

  async removeRole(role: Role) {
    const { code } = await Apis.removeRole(role);
    return code === "ok";
  }

  async findAllRoleWithPermissions() {
    const { code, data } = await Apis.findAllRoleWithPermissions();
    return data as {
      allPermissions: Permission[];
      roleWithPermissions: Role[];
    };
  }

  async findRolePermissions(id: number) {
    const { code, data } = await Apis.findRolePermissions(id);
    return data;
  }

  async saveRolePermissions(permissionIds: string[], roleId: number) {
    const { code } = await Apis.saveRolePermissions(permissionIds, roleId);
    return code === "ok";
  }

  async findAllUser() {
    const { code, data } = await Apis.findAllUser();
    return data as User[];
  }

  async saveUser(user: User) {
    const { code } = await Apis.saveUser(user);
    return code === "ok";
  }

  async updateUser(user: Omit<User, "roles"> & { roles: number[] }) {
    const { code } = await Apis.updateUser(user);
    return code === "ok";
  }

  async deleteUser(userIds: number[]) {
    const { code } = await Apis.deleteUser(userIds);
    return code === "ok";
  }
}
