import { Role } from "@@/domain/Rbac/entities/Role";
import { Request } from "./Request";
import { User } from "@@/domain/Rbac/entities/User";

const PREFIX = "/cert";

type ResponseType = Promise<{
  code?: number | string;
  data?: unknown;
  msg?: string;
}>;

export const Apis = {
  /**
   * 创建新角色
   * @param {Role} p
   */
  saveRole: (p: Role): ResponseType =>
    Request.post(PREFIX + "/admin/role/create", p),

  /**
   * 编辑角色
   * @param {Role} p
   */
  updateRole: (p: Role): ResponseType =>
    Request.post(PREFIX + "/admin/role/update", p),

  /**
   * 删除角色
   */
  removeRole: (p: Role): ResponseType =>
    Request.post(PREFIX + "/admin/role/remove", p),

  /**
   * 获取全部角色权限
   */
  findAllRoleWithPermissions: (): ResponseType =>
    Request.get(PREFIX + "/admin/find/role/all"),

  /**
   * 根据id查询全部的permissions信息
   * @param {number} id 角色Role的id
   */
  findRolePermissions: (id: number): ResponseType =>
    Request.post(PREFIX + "/admin/role/permissions/find", { id }),

  /**
   * 更新某个角色的权限
   * @param {string[]} permissionIds 权限id字符串数组
   * @param {number} roleId 角色id
   */
  saveRolePermissions: (
    permissionIds: string[],
    roleId: number
  ): ResponseType =>
    Request.post(PREFIX + "/admin/role/permissions/update", {
      permissionIds,
      roleId,
    }),
  /**
   * 查询全部用户
   */
  findAllUser: (): ResponseType => Request.get(PREFIX + "/admin/user/find/all"),

  /**
   * 创建用户
   */
  saveUser: (user: User): ResponseType =>
    Request.post(PREFIX + "/admin/user/create", user),
  /**
   * 修改用户
   */
  updateUser: (user: Omit<User, "roles"> & { roles: number[] }): ResponseType =>
    Request.post(PREFIX + "/admin/user/update", user),

  /**
   * 删除用户
   * @param {number[]} userIds 用户id数组
   */
  deleteUser: (userIds: number[]): ResponseType =>
    Request.post(PREFIX + "/admin/user/delete", userIds),
};
