import { Menu, MenuProps } from "antd";
import { Outlet, useLocation, useNavigate } from "react-router";
import {
  AiFillSetting,
  AiOutlineApartment,
  AiOutlineApi,
  AiOutlineNodeIndex,
  AiOutlineUser,
} from "react-icons/ai";
import "./index.less";
import { useEffect, useState } from "react";

interface LayoutProps {
  children?: JSX.Element;
}

type MenuItem = Required<MenuProps>["items"][number];

function getItem(
  label: React.ReactNode,
  key: React.Key,
  icon?: React.ReactNode,
  children?: MenuItem[],
  type?: "group"
): MenuItem {
  return {
    key,
    icon,
    children,
    label,
    type,
  } as MenuItem;
}

const items: MenuItem[] = [
  getItem("配置", "configuration", <AiFillSetting />, [
    getItem(
      "基本",
      "g1",
      null,
      [
        getItem("角色", "/configuration/role", <AiOutlineApartment />),
        getItem("资源权限", "/configuration/permission", <AiOutlineApi />),
      ],
      "group"
    ),
    getItem(
      "用户",
      "g2",
      null,
      [getItem("账户管理", "/user/management", <AiOutlineUser />)],
      "group"
    ),
  ]),
];

export const Layout = (props: LayoutProps) => {
  const navigate = useNavigate();
  const location = useLocation();
  const [selectedKeys, setSelectedKeys] = useState([location.pathname]);

  useEffect(() => setSelectedKeys([location.pathname]), [location.pathname]);

  return (
    <div className="layout-container">
      <header> {location.pathname}</header>
      <div>
        <aside>
          <Menu
            onClick={(e) => navigate(e.key)}
            style={{ width: "100%", height: "100%" }}
            selectedKeys={selectedKeys}
            defaultOpenKeys={["configuration"]}
            mode="inline"
            items={items}
          />
        </aside>
        <main>
          <Outlet />
        </main>
      </div>
    </div>
  );
};
