import {
  App,
  Button,
  Card,
  Form,
  Input,
  Modal,
  Select,
  Space,
  Table,
  TableColumnsType,
  Typography,
} from "antd";
import { ColumnsType } from "antd/es/table";
import axios from "axios";
import { useEffect, useState } from "react";
const { Text } = Typography;

interface PermissionProps {
  children?: JSX.Element;
}

interface PermissionItem {
  id: string;
  name: string;
  description?: string;
  resources: string[];
}

interface RbacConfigurationItem {
  moduleName: string;
  updateTime?: string;
  permissions: PermissionItem[];
}

export const Permission = (props: PermissionProps) => {
  const [dataSource, setDatasource] = useState<RbacConfigurationItem[]>([]);

  useEffect(() => {
    axios.get("/cert/admin/find/permission/resource").then((res) => {
      setDatasource(res.data.data);
    });
  }, []);

  const columnsOuter: ColumnsType<RbacConfigurationItem> = [
    {
      title: "模块",
      dataIndex: "moduleName",
      key: "moduleName",
    },
    {
      title: "更新时间",
      dataIndex: "updateTime",
      key: "updateTime",
    },
  ];

  const expandedRowRender = (record: any) => {
    const columnsInner: TableColumnsType<PermissionItem> = [
      {
        title: "标识",
        dataIndex: "id",
        key: "id",
      },
      {
        title: "权限",
        dataIndex: "name",
        key: "name",
      },
      {
        title: "映射资源",
        dataIndex: "resources",
        key: "resources",
        render: (_, record) => (
          <Space>
            {record.resources.map((i) => (
              <Text key={i} code>
                {i}
              </Text>
            ))}
          </Space>
        ),
      },
      {
        title: "描述",
        dataIndex: "description",
        key: "description",
        render: (_, record) => (
          <Text type="secondary">{record.description}</Text>
        ),
      },
    ];
    return (
      <Table
        columns={columnsInner}
        rowKey={(r) => r.id}
        dataSource={record.permissions}
        pagination={false}
      />
    );
  };

  return (
    <div>
      <Table
        columns={columnsOuter}
        rowKey={(r) => r.moduleName}
        dataSource={dataSource}
        expandable={{ expandedRowRender, expandRowByClick: true }}
      />
    </div>
  );
};
