import {
  Button,
  Divider,
  Form,
  Input,
  Modal,
  Popconfirm,
  Space,
  Typography,
} from "antd";
import {
  StopOutlined,
  DeleteOutlined,
  CheckOutlined,
  EditOutlined,
} from "@ant-design/icons";
import { useDomain } from "@/hook/useDomain";
import { observer } from "mobx-react-lite";
import { useState } from "react";
const { Text } = Typography;

export const RoleBaseInfo = observer(() => {
  const { rbacDomainService } = useDomain();
  const { activeRole } = rbacDomainService;
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [form] = Form.useForm();

  const onUpdateRole = (isEnabled: boolean) => {
    const { activeRole } = rbacDomainService;
    if (activeRole) {
      activeRole.isEnabled = isEnabled;
      rbacDomainService.updateRole(activeRole);
    }
  };

  const onRoleDelete = () => {
    const { activeRole } = rbacDomainService;
    if (activeRole) rbacDomainService.removeRole(activeRole);
  };

  const onEditRoleName = async () => {
    try {
      await form.validateFields();
      const { alias } = (await form.getFieldsValue()) as { alias: string };
      if (activeRole) {
        activeRole.alias = alias;
        rbacDomainService.updateRole(activeRole);
        setIsModalOpen(false);
      }
    } catch (error) {
      console.log(error);
    }
  };

  return (
    activeRole && (
      <div>
        <Space>
          <Text style={{ fontSize: 20 }}>{activeRole.alias}</Text>
          <Divider type="vertical" />
          {activeRole.isEnabled ? (
            <Space>
              <Popconfirm
                title="禁用"
                description="角色下用户无法正常使用业务系统, 确定?"
                onConfirm={() => onUpdateRole(false)}
                okText="确定"
                cancelText="取消"
              >
                <Button danger size="small" icon={<StopOutlined />}>
                  禁用
                </Button>
              </Popconfirm>
            </Space>
          ) : (
            <Popconfirm
              title="启用"
              description="确定要启用这个角色?"
              onConfirm={() => onUpdateRole(true)}
              okText="确定"
              cancelText="取消"
            >
              <Button size="small" type="primary" icon={<CheckOutlined />}>
                启用
              </Button>
            </Popconfirm>
          )}
          <Button
            size="small"
            onClick={() => {
              setIsModalOpen(true);
              form.setFieldsValue({ alias: activeRole.alias });
            }}
            type="text"
            icon={<EditOutlined />}
          >
            修改名称
          </Button>
          <Modal
            title="修改分类名称"
            width={320}
            open={isModalOpen}
            onOk={onEditRoleName}
            onCancel={() => setIsModalOpen(false)}
            cancelText="取消"
            okText="确认"
          >
            <Form form={form}>
              <Form.Item
                name="alias"
                style={{ marginBottom: 0 }}
                rules={[{ required: true, message: "不能为空" }]}
              >
                <Input placeholder="请输入" />
              </Form.Item>
            </Form>
          </Modal>
          <Popconfirm
            title="禁用"
            description="高危操作, 确定?"
            onConfirm={() => onRoleDelete()}
            okText="确定"
            cancelText="取消"
          >
            <Button size="small" type="text" danger icon={<DeleteOutlined />}>
              删除
            </Button>
          </Popconfirm>
        </Space>
        <p>
          <Text style={{ fontSize: 14, color: "#919191" }}>
            {activeRole.description}
          </Text>
        </p>
      </div>
    )
  );
});
