import { CheckboxValueType } from "antd/es/checkbox/Group";
import { RbacService } from "@@/domain/Rbac/RbacService";
import { Checkbox, Tabs, TabsProps } from "antd";
import { useDomain } from "@/hook/useDomain";
import { observer } from "mobx-react-lite";
import { RoleUsersTable } from "./RoleUsersTable";

export const EditTab = () => {
  const { rbacDomainService } = useDomain();

  const CheckOptionsComponent: React.FC<{ domainService: RbacService }> =
    observer(({ domainService }) => {
      const { allPermissions, activeRole } = domainService;
      return (
        <Checkbox.Group
          options={allPermissions.map((p) => p.name)}
          value={activeRole?.permissions?.map((p) => p.name) ?? []}
          onChange={(list: CheckboxValueType[]) => {
            if (activeRole) {
              activeRole.permissions = allPermissions.filter((p) =>
                list.includes(p.name)
              );
              domainService.updateRole(activeRole);
            }
          }}
        />
      );
    });

  const items: TabsProps["items"] = [
    {
      key: "1",
      label: "成员",
      children: <RoleUsersTable domainService={rbacDomainService} />,
    },
    {
      key: "2",
      label: "角色权限",
      children: <CheckOptionsComponent domainService={rbacDomainService} />,
    },
  ];

  return <Tabs defaultActiveKey="1" items={items} />;
};
