import { Form, Input, Modal, message } from "antd";
import { useState } from "react";

export type fieldsType = {
  name: string;
  alias: string;
  description?: string;
};

interface RoleAddModalProps {
  onOk?: (fields: fieldsType) => Promise<void> | void;
}

export const useRoleAddModal = () => {
  const [form] = Form.useForm();
  const [messageApi, contextHolder] = message.useMessage();
  const [modalVisible, setModalVisible] = useState(false);

  const RoleAddModal = (props: RoleAddModalProps) => {
    /**
     * 确认
     */
    const onOkHandler = async () => {
      try {
        await form.validateFields();
        const fields = form.getFieldsValue() as fieldsType;
        props.onOk?.(fields);
      } catch (error) {
        console.log(error);
      }
    };

    return (
      <Modal
        open={modalVisible}
        onOk={() => onOkHandler()}
        cancelText="取消"
        onCancel={() => setModalVisible(false)}
        title="新增角色"
      >
        <Form
          form={form}
          style={{ marginTop: 40 }}
          labelAlign="left"
          wrapperCol={{ span: 18 }}
          labelCol={{ span: 6 }}
          initialValues={{
            name: "",
            alias: "",
            description: "",
          }}
        >
          <Form.Item
            label="角色标识"
            name="name"
            rules={[
              { required: true, message: "请输入角色英文标识" },
              {
                pattern: new RegExp(/^[a-z_$][0-9a-z_$]*$/),
                message:
                  "第一个字符必须是字母, 后续字符可以是任意数字、字母、美元符号($)或者下划线",
              },
            ]}
          >
            <Input placeholder="英文" />
          </Form.Item>
          <Form.Item
            label="名称"
            name="alias"
            rules={[{ required: true, message: "请输入角色中文名" }]}
          >
            <Input placeholder="中文" />
          </Form.Item>
          <Form.Item label="描述" name="description">
            <Input placeholder="描述这个角色" />
          </Form.Item>
        </Form>
      </Modal>
    );
  };

  return { setModalVisible, messageApi, contextHolder, RoleAddModal };
};
