import { CheckOutlined, StopOutlined } from "@ant-design/icons";
import { Menu, MenuProps } from "antd";

export interface RoleItem {
  id: number;
  name: string;
  alias: string;
  isEnabled: boolean;
  description: string;
  active: boolean;
}

interface RoleListProps {
  children?: JSX.Element;
  dataSource: RoleItem[];
  onClick?: (item: RoleItem) => void;
}

type MenuItem = Required<MenuProps>["items"][number];

export const RoleList = (props: RoleListProps) => {
  const { dataSource } = props;
  const onClickRoleItem = ({ key }: { key: string }) => {
    const item = dataSource.find((i) => i.id === Number(key)) as RoleItem;
    props.onClick?.(item);
  };

  const items: MenuItem[] = dataSource.map((item: RoleItem) => ({
    label: item.alias,
    key: item.id,
    icon: item.isEnabled ? (
      <CheckOutlined style={{ color: "#52c41a" }} />
    ) : (
      <StopOutlined style={{ color: "#ff4d4f" }} />
    ),
  }));

  return (
    <Menu
      style={{ borderRight: 0 }}
      onClick={onClickRoleItem}
      theme="light"
      mode="vertical"
      items={items}
    />
  );
};
