import { fieldsType, useRoleAddModal } from "./components/RoleAddModal";
import { RoleBaseInfo } from "./components/EditTab/RoleBaseInfo";
import { RoleItem, RoleList } from "./components/RoleList";
import { RbacService } from "@@/domain/Rbac/RbacService";
import { EditTab } from "./components/EditTab";
import { useDomain } from "@/hook/useDomain";
import { observer } from "mobx-react-lite";
import { Button, Divider } from "antd";
import { useEffect } from "react";
import "./index.less";
interface RoleProps {
  children?: JSX.Element;
}

export const Role = (props: RoleProps) => {
  const { rbacDomainService } = useDomain();
  const { RoleAddModal, setModalVisible, messageApi, contextHolder } =
    useRoleAddModal();

  useEffect(() => {
    rbacDomainService.findAllRoleWithPermissions();
  }, [rbacDomainService]);

  const clickRoleItemHandler = (role: RoleItem) =>
    rbacDomainService.setActiveRole(role);

  const onModalConfirm = async (fields: fieldsType) => {
    setModalVisible(false);
    const ok = await rbacDomainService.addRole({ ...fields });
    messageApi.info(ok ? "ok" : "failed");
  };

  const RoleListComponent: React.FC<{ domainService: RbacService }> = observer(
    ({ domainService }) => {
      const { activeRole } = domainService;
      const dataSource = domainService.roleList.map((r) => ({
        ...r,
        active: r.id === activeRole?.id,
      })) as RoleItem[];
      return (
        <RoleList dataSource={dataSource} onClick={clickRoleItemHandler} />
      );
    }
  );

  return (
    <div className="role-container">
      <aside>
        <>
          <Button
            type="primary"
            size="small"
            onClick={() => setModalVisible(true)}
          >
            新增
          </Button>
          {contextHolder}
          <RoleAddModal onOk={onModalConfirm} />
        </>
        <Divider orientation="center" style={{ fontSize: 13 }}>
          角色列表
        </Divider>
        <RoleListComponent domainService={rbacDomainService} />
      </aside>
      <main>
        <RoleBaseInfo />
        <EditTab />
      </main>
    </div>
  );
};
