import { Button, Form, Input, Select, message } from "antd";
import { useDomain } from "@/hook/useDomain";
import { Observer } from "mobx-react-lite";
import { useEffect } from "react";

export interface CreateUserFormFields {
  roleIds: number[];
  username: string;
  password: string;
  phoneNumber: string;
}

interface CreateUserFormProps {
  children?: JSX.Element;
}

export const CreateUserForm = (props: CreateUserFormProps) => {
  const [form] = Form.useForm();
  const { rbacDomainService } = useDomain();
  const [messageApi, contextHolder] = message.useMessage();

  useEffect(() => {
    rbacDomainService.findAllRoleWithPermissions();
  }, [rbacDomainService]);

  const onConfirmCreateUser = async (fields: CreateUserFormFields) => {
    const { roleIds, username, password, phoneNumber } = fields;
    const success = await rbacDomainService.saveUser({
      roleIds,
      username,
      password,
      phoneNumber,
    });
    if (success) messageApi.success(`用户: ${username} 创建成功`);
  };

  return (
    <div style={{ padding: 20 }}>
      {contextHolder}
      <Observer>
        {() => (
          <Form form={form} layout="inline" onFinish={onConfirmCreateUser}>
            <Form.Item name="username" rules={[{ required: true }]}>
              <Input placeholder="用户名" />
            </Form.Item>
            <Form.Item name="password" rules={[{ required: true }]}>
              <Input.Password placeholder="密码" />
            </Form.Item>
            <Form.Item name="phoneNumber" rules={[{ required: true }]}>
              <Input placeholder="手机号" />
            </Form.Item>
            <Form.Item name="roleIds" style={{ minWidth: 220 }}>
              <Select
                placeholder="角色，可多选"
                allowClear
                mode="multiple"
                options={rbacDomainService.allRoles.map((r) => ({
                  value: r.id,
                  label: r.alias,
                }))}
              />
            </Form.Item>
            <Form.Item>
              <Button type="primary" htmlType="submit">
                创建
              </Button>
            </Form.Item>
          </Form>
        )}
      </Observer>
    </div>
  );
};
