import { User } from "@@/domain/Rbac/entities/User";
import { Checkbox, Form, Input, Modal, Select } from "antd";
import { useEffect, useState } from "react";

export interface UserEditForm {
  isEnabled: boolean;
  phoneNumber: string;
  password: string | undefined;
  roleIds: number[];
}

interface UserEditModalProps {
  children?: JSX.Element;
  editUser: User;
  roleOptions: { value: number; label: string }[];
  onConfirm?: (fields: UserEditForm) => void;
}

export const useUserEditModal = () => {
  const [modalVisible, setModalVisible] = useState(true);
  const [form] = Form.useForm<UserEditForm>();

  const UserEditModal = (props: UserEditModalProps) => {
    const { phoneNumber, isEnabled, username, roles } = props.editUser;
    const roleIds = roles?.map((r) => r.id!);

    useEffect(() => {
      form.setFieldsValue({ phoneNumber, roleIds, isEnabled });
    }, [isEnabled, phoneNumber, roleIds]);

    const onOkHandler = async () => {
      try {
        await form.validateFields();
        props.onConfirm?.(form.getFieldsValue());
        form.resetFields();
      } catch (error) {
        console.log(error);
      }
    };
    return (
      <Modal
        open={modalVisible}
        width={320}
        onOk={onOkHandler}
        okText="确认"
        cancelText="取消"
        onCancel={() => setModalVisible(false)}
        title={`编辑用户 ${username!}`}
      >
        <Form layout="vertical" form={form}>
          <Form.Item name="isEnabled" valuePropName="checked">
            <Checkbox>启用</Checkbox>
          </Form.Item>
          <Form.Item name="phoneNumber">
            <Input placeholder="手机号" />
          </Form.Item>
          <Form.Item name="password">
            <Input.Password placeholder="新密码" />
          </Form.Item>
          <Form.Item label="角色" name="roleIds" style={{ minWidth: 120 }}>
            <Select
              placeholder="可多选"
              allowClear
              mode="multiple"
              options={props.roleOptions}
            />
          </Form.Item>
        </Form>
      </Modal>
    );
  };

  return { UserEditModal, setModalVisible };
};
