import {
  CheckOutlined,
  ContainerOutlined,
  EditOutlined,
  StopOutlined,
} from "@ant-design/icons";
import { User } from "@@/domain/Rbac/entities/User";
import { Button, Popconfirm, Space, Table, Tag, Tooltip } from "antd";
import { ColumnsType } from "antd/es/table";
import { observer } from "mobx-react-lite";
import { RbacService } from "@@/domain/Rbac/RbacService";
import { useState } from "react";

interface UserTableProps {
  domainService: RbacService;
  onClickEdit?: (record: any) => void;
  onClickLogView?: (record: any) => void;
  onDelete?: (rowKeys: React.Key[]) => void;
}

export const UserTableList: React.FC<UserTableProps> = observer(
  ({ domainService, onClickEdit, onDelete, onClickLogView }) => {
    const columns: ColumnsType<User> = [
      {
        key: "id",
        dataIndex: "id",
        title: "#",
      },
      {
        key: "isEnabled",
        title: "可用",
        render: (_, record: User) => {
          return record.isEnabled ? (
            <CheckOutlined style={{ color: "#52c41a" }} />
          ) : (
            <StopOutlined style={{ color: "#ff4d4f" }} />
          );
        },
      },
      {
        key: "username",
        dataIndex: "username",
        title: "用户名",
      },
      {
        key: "role",
        title: "角色",
        render: (_, record: User) => {
          return record.roles?.map((i) => <Tag key={i.id}>{i.alias}</Tag>);
        },
      },
      {
        key: "phoneNumber",
        dataIndex: "phoneNumber",
        title: "手机号",
      },
      {
        key: "createTime",
        dataIndex: "createTime",
        title: "创建时间",
        render: (_, record) => {
          const formateDate = new Date(
            record.createTime ?? ""
          ).toLocaleString();
          return <span>{formateDate}</span>;
        },
      },
      {
        key: "editUser",
        title: "编辑用户",
        render: (_, record) => {
          return (
            <Space>
              <Button
                type="text"
                onClick={() => {
                  onClickEdit?.({ ...record });
                }}
                icon={<EditOutlined />}
              />
              <Tooltip title="用户日志">
                <Button
                  type="text"
                  onClick={() => {
                    onClickLogView?.({ ...record });
                  }}
                  icon={<ContainerOutlined />}
                />
              </Tooltip>
            </Space>
          );
        },
      },
    ];

    const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

    const rowSelection = {
      selectedRowKeys,
      onChange: (rowKeys: React.Key[]) => setSelectedRowKeys(rowKeys),
    };

    return (
      <div>
        <header style={{ padding: 20 }}>
          <Space>
            {selectedRowKeys.length > 0 && (
              <Popconfirm
                title="危险操作"
                description="你确定要删除这些用户吗？"
                onConfirm={() => onDelete?.(selectedRowKeys)}
                okText="确定"
                cancelText="取消"
              >
                <Button type="primary" danger>
                  删除
                </Button>
              </Popconfirm>
            )}
          </Space>
        </header>
        <Table
          rowKey={(r) => r.id!}
          rowSelection={rowSelection}
          dataSource={domainService.userList}
          columns={columns}
        />
      </div>
    );
  }
);
