import { UserEditForm, useUserEditModal } from "./UserEditModal";
import { User } from "@@/domain/Rbac/entities/User";
import { CreateUserForm } from "./CreateUserForm";
import { useEffect, useState } from "react";
import { UserTableList } from "./UserTable";
import { useDomain } from "@/hook/useDomain";
import { message } from "antd";
import { useNavigate } from "react-router";

interface UserManagementProps {
  children?: JSX.Element;
}

export const UserManagement = (props: UserManagementProps) => {
  const { UserEditModal, setModalVisible } = useUserEditModal();
  const [messageApi, contextHolder] = message.useMessage();
  const navigate = useNavigate();

  const [editUser, setEditUser] = useState<User>();
  const { rbacDomainService } = useDomain();
  const { allRoles } = rbacDomainService;
  const rolesForSelectOptions = allRoles.map((r) => ({
    value: r.id!,
    label: r.alias,
  }));

  useEffect(() => {
    rbacDomainService.findAllUser();
  }, [rbacDomainService]);

  const onClickUserEditHandler = (user: User) => {
    setEditUser(user);
    setModalVisible(true);
  };

  const onUserEditConfirmHandler = async (form: UserEditForm) => {
    const { roleIds, password, phoneNumber, isEnabled } = form;
    const roles = allRoles.filter((r) => roleIds.includes(r.id!));
    const { id, username } = editUser!;
    const user = {
      password,
      phoneNumber,
      isEnabled,
      roles,
      id,
      username,
    };
    await rbacDomainService.updateUser(user, roleIds);
    setModalVisible(false);
    setEditUser(undefined);
  };

  const onClickUserDeleteHandler = async (userIds: React.Key[]) => {
    const ids = userIds.map((id) => Number(id));
    const success = await rbacDomainService.deleteUser(ids);
    if (success) messageApi.success(`共删除${userIds.length}个用户`);
  };

  const onClickLogViewHandler = (user: User) => {
    const { id, username, roles } = user;
    const hasRoles = roles?.map((r) => r.alias);
    const state = { id, username, hasRoles };
    navigate("/user/audit", { state });
  };

  return (
    <div>
      {contextHolder}
      <CreateUserForm />
      <UserTableList
        domainService={rbacDomainService}
        onClickEdit={onClickUserEditHandler}
        onClickLogView={onClickLogViewHandler}
        onDelete={onClickUserDeleteHandler}
      />
      {editUser && (
        <UserEditModal
          roleOptions={rolesForSelectOptions}
          editUser={editUser}
          onConfirm={onUserEditConfirmHandler}
        />
      )}
    </div>
  );
};
