import { makeAutoObservable } from "mobx";

interface UserProps {
  id?: number | string | undefined;
  username?: string;
  password?: string;
  isEnabled?: boolean;
  isLoggedIn?: boolean;
}

export class User {
  id?: number | string;
  username?: string;
  password?: string;
  isEnabled?: boolean;
  isLoggedIn?: boolean;
  roles: any[] | undefined;

  constructor(props: UserProps = {}) {
    this.id = props.id;
    this.username = props.username;
    this.password = props.password;
    this.isEnabled = props.isEnabled;
    this.isLoggedIn = false;
    makeAutoObservable(this);
  }

  signIn(user: User) {
    this.isLoggedIn = true;
    this.username = user.username;
    this.roles = user.roles;
  }

  signOut() {
    this.isLoggedIn = false;
  }

  /**
   * 获取用户拥有的角色名数组
   */
  getRolesNames() {
    return this.roles?.map((r: { name: string }) => r.name);
  }
}
