import { useEffect, useState } from "react";
import { useNavigate } from "react-router";
import { Menu, MenuProps } from "antd";

export type MenuItem = Required<MenuProps>["items"][number];

type RoleMenusType = {
  menuItems: MenuItem[];
};

export const getItem = (
  label: React.ReactNode,
  key: React.Key,
  icon?: React.ReactNode,
  children?: MenuItem[],
  type?: "group"
): MenuItem => {
  return {
    key,
    icon,
    children,
    label,
    type,
  } as MenuItem;
};

export const useMenu = () => {
  const navigate = useNavigate();
  const [selectedKeys, setSelectedKeys] = useState([location.pathname]);

  useEffect(() => setSelectedKeys([location.pathname]), [location.pathname]);

  const LeftMenu = (props: RoleMenusType) => {
    const { menuItems } = props;
    return menuItems.length > 0 ? (
      <Menu
        onClick={(e) => navigate(e.key)}
        style={{ width: "100%", height: "100%" }}
        selectedKeys={selectedKeys}
        defaultOpenKeys={["dicom"]}
        mode="inline"
        items={menuItems}
      />
    ) : (
      <span></span>
    );
  };

  return { LeftMenu };
};
