import { DicomRepository } from "@@/domain/Dicom/DicomRepository";
import { DicomService } from "@@/domain/Dicom/DicomService";
import { UserRepository } from "@@/domain/User/UserRepository";
import { UserService } from "@@/domain/User/UserService";
import { createContext } from "react";

export type Services = {
  userDomainService: UserService;
  dicomDomainService: DicomService;
};

const defaultServiceMap = {
  userDomainService: new UserService(new UserRepository()),
  dicomDomainService: new DicomService(new DicomRepository()),
};

export const DomainServiceContext = createContext<Services>(defaultServiceMap);

interface DomainServiceProviderProps {
  children?: JSX.Element;
}

export const DomainServiceProvider = (props: DomainServiceProviderProps) => {
  return (
    <DomainServiceContext.Provider value={defaultServiceMap}>
      {props.children}
    </DomainServiceContext.Provider>
  );
};
