import { columnsForSeries, columnsForStudy } from "./columns";
import { EyeOutlined, TagOutlined } from "@ant-design/icons";
import { Series, Study } from "../DicomUploader/util";
import { Button, Space, Table, Tooltip } from "antd";
interface DicomTableProps {
  studys: Study[];
  loading?: boolean;
  onSelectedRows?: (rows: Study[]) => void;
  onUploadFiles?: (study: Study, series: Series) => void;
}

export const DicomTable = (props: DicomTableProps) => {
  const { studys } = props;

  /**
   * 序列级别
   */
  const expandedRowRenderForSeries = (record: Study) => {
    return (
      <Table
        rowKey="SeriesInstanceUID"
        columns={[
          ...columnsForSeries,
          {
            title: "操作",
            dataIndex: "operation",
            render: (_: any, recordSeries: Series) => (
              <Space>
                <Button
                  type="primary"
                  size="small"
                  icon={<EyeOutlined />}
                  onClick={() => props.onUploadFiles?.(record, recordSeries)}
                >
                  阅片
                </Button>
              </Space>
            ),
          },
        ]}
        dataSource={record.subs}
        pagination={false}
      />
    );
  };

  return (
    <Table
      dataSource={studys}
      loading={props.loading}
      rowSelection={{
        type: "checkbox",
        onChange: (selectedRowKeys: React.Key[], selectedRows: Study[]) =>
          props.onSelectedRows?.(selectedRows),
      }}
      columns={[
        ...columnsForStudy,
        {
          title: "操作",
          dataIndex: "operation",
          render: (_: any, record: Study) => (
            <Space>
              <Tooltip title="病例添加标签">
                <Button type="text" size="small" icon={<TagOutlined />} />
              </Tooltip>
            </Space>
          ),
        },
      ]}
      expandable={{
        expandedRowRender: expandedRowRenderForSeries,
      }}
      rowKey="StudyInstanceUID"
    />
  );
};
