import React, { useRef, useState } from "react";
import { Study, parseDcmFiles } from "./util";
import { Button } from "antd";
import { FolderOutlined } from "@ant-design/icons";

declare module "react" {
  interface InputHTMLAttributes<T> extends HTMLAttributes<T> {
    webkitdirectory?: string;
    mozdirectory?: string;
  }
}

type FileCalculator = {
  dcmFileNum: number | string;
  totalFileNum: number | string;
  dcmFileSize: number | string;
};

export const useDicomUploader = () => {
  const [fileCalculator, setFileCalculator] = useState<FileCalculator>({
    dcmFileNum: "",
    totalFileNum: "",
    dcmFileSize: "",
  });
  const [isLoading, setIsLoading] = useState(false);
  const fileInputRef = useRef<HTMLInputElement | null>(null);
  const [studys, setStudys] = useState<Study[]>([]);

  const handleFileChange = async (e: React.ChangeEvent<HTMLInputElement>) => {
    e.persist();
    if (!fileInputRef.current?.files) return;
    const files = Array.from(fileInputRef.current.files);
    const dcmFiles = files.filter((file) => file.name.endsWith(".dcm"));
    const totalSize = [...files].reduce((sum, file) => sum + file.size, 0);
    const size2GB: number = totalSize / (1024 * 1024);

    setFileCalculator({
      dcmFileNum: dcmFiles.length,
      totalFileNum: files.length,
      dcmFileSize: size2GB.toFixed(2) + " MB",
    });
    //TODO: 耗时
    setIsLoading(true);
    const studys = await parseDcmFiles(dcmFiles);
    setStudys(studys);
    setIsLoading(false);
  };

  const UploadInput = () => {
    return (
      <>
        <input
          type="file"
          webkitdirectory="true"
          ref={fileInputRef}
          mozdirectory="true"
          multiple
          style={{ display: "none" }}
          onChange={(e) => handleFileChange(e)}
        />
        <Button
          icon={<FolderOutlined />}
          type="primary"
          onClick={() => fileInputRef.current?.click()}
        >
          选择dicom
        </Button>
      </>
    );
  };

  return { UploadInput, fileCalculator, studys, isLoading };
};
