import * as dicomParser from "dicom-parser";

export interface Series {
  SeriesInstanceUID: string;
  SliceThickness: string;
  SeriesDescription: string;
  /**
   * 成像设备
   */
  Modality: string;
  /**
   * 设备商
   */
  Manufacturer: string;
  subs: File[];
}

export interface Study {
  StudyInstanceUID: string;
  StudyDescription: string;
  PatientID: string;
  PatientAge: string;
  PatientName: string;
  PatientSex: string;
  AcquisitionDate: string;
  subs: Series[];
}

/**
 * 结构化解析dcmFiles
 * @param {File[]} dcmFiles 上传浏览器读取的File类
 */
export const parseDcmFiles = async (dcmFiles: File[]): Promise<Study[]> => {
  const studys: Study[] = [];

  for (const file of dcmFiles) {
    const arrayBuffer = await file.arrayBuffer();
    const byteArray = new Uint8Array(arrayBuffer);
    const dataSet = dicomParser.parseDicom(byteArray);

    const PatientID = dataSet.string("x00100020") ?? "无";
    const StudyInstanceUID = dataSet.string("x0020000d");
    const StudyDescription = dataSet.string("x00081030") ?? "无";
    const SeriesInstanceUID = dataSet.string("x0020000e");
    const PatientName = dataSet.string("x00100010") ?? "无";
    const PatientSex = dataSet.string("x00100040") ?? "无";
    const PatientAge = dataSet.string("x00101010") ?? "无";
    const SliceThickness = dataSet.string("x00180050");
    const AcquisitionDate = dataSet.string("x00080022") ?? "无";
    const SeriesDescription = dataSet.string("x0008103e") ?? "无";
    const Modality = dataSet.string("x00080060") ?? "无";
    const Manufacturer = dataSet.string("x00081090") ?? "无";

    if (StudyInstanceUID && SeriesInstanceUID && SliceThickness) {
      // 病例级别
      let study = studys.find((s) => s.StudyInstanceUID === StudyInstanceUID);
      if (!study) {
        study = {
          StudyInstanceUID,
          StudyDescription,
          PatientID,
          PatientName,
          PatientSex,
          PatientAge,
          AcquisitionDate,
          subs: [],
        };
        studys.push(study);
      }
      // 序列级别，可能会存在某个序列被复制一份的情况，也会计算在切片数量中
      let series = study.subs.find(
        (s) => s.SeriesInstanceUID === SeriesInstanceUID
      );
      if (!series) {
        series = {
          SeriesInstanceUID,
          SliceThickness,
          SeriesDescription,
          Modality,
          Manufacturer,
          subs: [],
        };
        study.subs.push(series);
      }
      series.subs.push(file);
    }
  }
  return studys;
};
