type PromiseFunction = () => Promise<any>;

export async function limitConcurrency(
  tasks: PromiseFunction[],
  maxConcurrency: number,
  onProgress?: (completed: number, total: number) => void,
  onComplete?: () => void
): Promise<any[]> {
  const results: any[] = new Array(tasks.length);
  let currentIndex = 0;
  let completedTasks = 0;

  return new Promise((resolve, reject) => {
    function executeTask() {
      const index = currentIndex;
      currentIndex += 1;

      if (index >= tasks.length) return;

      const task = tasks[index];

      task()
        .then((result) => {
          results[index] = result;
          completedTasks++;
          if (onProgress) {
            onProgress(completedTasks, tasks.length);
          }
          // 当所有任务都完成时触发
          if (completedTasks === tasks.length) {
            resolve(results);
            if (onComplete) {
              onComplete();
            }
          }
          executeTask();
        })
        .catch((err) => {
          reject(err);
        });
    }

    for (let i = 0; i < Math.min(maxConcurrency, tasks.length); i++) {
      executeTask();
    }
  });
}
