import { Button, Form, Input, message } from "antd";
import { useDomain } from "@/hook/useDomain";
import "./index.less";
import { useNavigate } from "react-router";

interface LoginProps {
  children?: JSX.Element;
}

export const Login = (props: LoginProps) => {
  const { userDomainService } = useDomain();
  const [messageApi, contextHolder] = message.useMessage();
  const navigate = useNavigate();

  const onFinish = (values: { username: string; password: string }) => {
    userDomainService.signIn(values).then((result) => {
      const { success, msg } = result;
      if (success) {
        messageApi.success(msg);
        navigate("/");
      } else {
        messageApi.error(msg);
      }
    });
  };

  return (
    <div
      className="login-container"
      style={{ backgroundImage: `url('/wave.svg')` }}
    >
      <Form
        name="basic"
        layout="vertical"
        style={{ width: 300 }}
        onFinish={onFinish}
        autoComplete="off"
      >
        <Form.Item
          label="用户名"
          name="username"
          rules={[{ required: true, message: "请输入您的用户名" }]}
        >
          <Input />
        </Form.Item>

        <Form.Item
          label="密码"
          name="password"
          rules={[{ required: true, message: "请输入您的密码" }]}
        >
          <Input.Password />
        </Form.Item>
        <Form.Item>
          <Button block type="primary" htmlType="submit">
            登录
          </Button>
        </Form.Item>
      </Form>
      {contextHolder}
    </div>
  );
};
