import { useDomain } from "@/hook/useDomain";
import React from "react";
import { useLocation, useNavigate } from "react-router";
import { pathToRegexp } from "path-to-regexp";
import { AuthFailedReplacePath } from "@/constant";

interface RouteGuardProps {
  children?: React.ReactNode;
  ignorePaths: string[];
}

export const RouteGuard = (props: RouteGuardProps) => {
  const { children, ignorePaths } = props;
  const { userDomainService } = useDomain();
  const { user } = userDomainService;
  const location = useLocation();
  const navigate = useNavigate();

  const ignore = ignorePaths.some((p) =>
    pathToRegexp(p).test(location.pathname)
  );

  if (!ignore && !user.isLoggedIn) {
    userDomainService.userAuth().then(({ success }) => {
      if (!success) navigate(AuthFailedReplacePath);
    });
  }

  return children;
};
