import { Route, RouteObject, Routes, useLocation } from "react-router-dom";
import { ROLE_NAME, defaultDocumentTitle } from "@/constant";
import { pathToRegexp } from "path-to-regexp";
import { useDomain } from "@/hook/useDomain";
import { observer } from "mobx-react-lite";
import { baseRoutes } from "./baseRoutes";
import { roleRoutes } from "./roleRoutes";
import { RouteGuard } from "./Guard";

export type ExpandRouteProps = {
  title?: string;
};

export const RouterElements = observer(() => {
  const { userDomainService } = useDomain();
  const { user } = userDomainService;
  const location = useLocation();

  /**
   * 用户拥有的角色名
   */
  const userRoleNames = user.getRolesNames() as ROLE_NAME[];

  /**
   * 根据角色生成路由
   */
  const currentRoutes =
    userRoleNames
      ?.map((n) => roleRoutes[n])
      .filter(Boolean)
      .flat() ?? [];

  /**
   * document.title
   */
  const currentRoute = [...currentRoutes, ...baseRoutes].find((r) =>
    pathToRegexp(r.path!).test(location.pathname)
  );
  if (currentRoute) document.title = currentRoute.title || defaultDocumentTitle;

  /**
   * 递归children
   */
  const generateRoutes = (routes: (RouteObject & ExpandRouteProps)[]) =>
    routes.map((r) => (
      <Route key={r.path} path={r.path} element={r.element}>
        {r.children && generateRoutes(r.children)}
      </Route>
    ));

  return (
    <RouteGuard ignorePaths={baseRoutes.map((r) => r.path!)}>
      <Routes>
        {generateRoutes(currentRoutes)}
        {generateRoutes(baseRoutes)}
      </Routes>
    </RouteGuard>
  );
});
