import {
  Controller,
  Get,
  Inject,
  Param,
  Post,
  Res,
  UploadedFile,
  UseInterceptors,
} from '@nestjs/common';
import { ClientProxy } from '@nestjs/microservices';
import { FileInterceptor } from '@nestjs/platform-express';
import { getFileExt } from './report.util';
import { clientConfig } from './report.config';
import { MinioOSS } from '@tavi/oss';
import { Response } from 'express';

@Controller('report')
export class ReportController {
  constructor(@Inject('Client') private client: ClientProxy) {}

  @Post('/upload')
  @UseInterceptors(FileInterceptor('file'))
  async report(@UploadedFile() file: Express.Multer.File) {
    try {
      const { buffer, originalname } = file;
      const objectName = Date.now() + '.' + getFileExt(originalname);
      const { bucketName, ...config } = clientConfig;
      const minio = new MinioOSS(config);
      const res = await minio.put({
        file: buffer,
        objectName,
        bucketName,
      });
      return { res, objectName };
    } catch (error) {
      console.log('error', error);
    }
  }

  @Get('/img/:name')
  getReportImage(@Param('name') objectName: string, @Res() res: Response) {
    const { bucketName, ...config } = clientConfig;
    const minio = new MinioOSS(config);
    minio.client.getObject('test', objectName, (err, dataStream) => {
      if (err) return res.status(500).send(err);
      dataStream.pipe(res);
    });
  }

  @Get('/root')
  async root() {
    return '123';
  }
}
