import { Inject, Injectable } from '@nestjs/common';
import { Redis } from 'ioredis';
import { RedisToken } from './redis.entity';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class RedisService {
  constructor(
    @Inject('Redis') private readonly redis: Redis,
    private configService: ConfigService,
  ) {}

  /**
   * 存储用户的token到redis中
   * @param {string|number} id 用户的唯一id、userId || openId
   * @param {string} token jwt生成的字符串
   */
  setToken(username: string, token: string) {
    const redisKey = new RedisToken({ id: username }).key();
    const expireSeconds = Number(this.configService.get('JWT_EXPIRES_IN'));
    this.redis.set(redisKey, token, 'EX', expireSeconds);
  }

  /**
   * 获取redis中用户的token
   * @param {string|number} key 用户的唯一id、userId || openId
   * @param {string} token jwt生成的字符串
   */
  async getToken(key: string | number) {
    const redisKey = new RedisToken({ id: String(key) }).key();
    return await this.redis.get(redisKey);
  }

  /**
   * 判断redis key是否在在redis当中
   */
  async tokenInRedis(key: string | number) {
    const redisKey = new RedisToken({ id: String(key) }).key();
    return (await this.redis.exists(redisKey)) === 1;
  }

  /**
   * 移除token
   */
  async removeToken(key: string | number) {
    const redisKey = new RedisToken({ id: String(key) }).key();
    return await this.redis.del(redisKey);
  }
}
