import { Module } from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { NacosModule } from './nacos/nacos.module';
import { ConfigModule } from '@nestjs/config';
import { TypeOrmModule } from '@nestjs/typeorm';
import { RbacModule } from './rbac/rbac.module';
import { User } from './rbac/entity/user.entity';
import { Role } from './rbac/entity/role.entity';
import { Permission } from './rbac/entity/permission.entity';
import { UserModule } from './user/user.module';

@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      envFilePath: `.env.${process.env.NODE_ENV}`,
    }),
    NacosModule,
    RbacModule,
    TypeOrmModule.forFeature([User, Role, Permission]),
    UserModule,
  ],
  controllers: [AppController],
  providers: [AppService],
  exports: [],
})
export class AppModule {}
