import { Body, Controller, Get, Inject, Param, Post } from '@nestjs/common';
import {
  AdminSignDto,
  CreateRoleDto,
  CreateUserDto,
  FindRoleDto,
  ForbidRoleDto,
  RoleDto,
  UpdateRolePermissionsDto,
  UpdateUserDto,
} from './admin.dto';
import { ClientProxy } from '@nestjs/microservices';
import { firstValueFrom } from 'rxjs';
import { rbacConfiguration } from 'src/resource.table';

@Controller('admin')
export class AdminController {
  constructor(@Inject('Client') private client: ClientProxy) {}

  @Get('find/permission/resource')
  async findRbacConfiguration(): Promise<any> {
    return { code: 'ok', data: rbacConfiguration };
  }

  @Post('role/create')
  async createRole(@Body() createRoleDto: CreateRoleDto) {
    const pattern = { cmd: 'cert.create.role' };
    const result = await firstValueFrom(
      this.client.send(pattern, createRoleDto),
    );
    return { code: 'ok', data: result };
  }

  @Post('role/remove')
  async removeRole(@Body() role: RoleDto) {
    const pattern = { cmd: 'cert.remove.role' };
    const result = await firstValueFrom(this.client.send(pattern, role));
    return { code: 'ok', data: result };
  }

  @Post('role/update')
  async updateRole(@Body() forbidRoleDto: ForbidRoleDto) {
    const pattern = { cmd: 'cert.update.role' };
    const payload = forbidRoleDto;
    const result = await firstValueFrom(this.client.send(pattern, payload));
    return { code: 'ok', data: result };
  }

  @Get('find/role/all')
  async findAllRolePermissions() {
    const pattern = { cmd: 'cert.find.role.all' };
    const result = await firstValueFrom(this.client.send(pattern, []));
    return { code: 'ok', data: result };
  }

  @Post('role/permissions/find')
  async findRolePermission(@Body() findRoleDto: FindRoleDto): Promise<any> {
    const pattern = { cmd: 'cert.find.role.permission' };
    const payload = findRoleDto.id;
    // 角色在role-permission关联表中已存在的权限
    const { permissions } = await firstValueFrom(
      this.client.send(pattern, payload),
    );
    const roleOwnPermissions = permissions.map((i) => ({
      id: i.id,
      name: i.name,
    }));
    // 结构化
    const allPermissions = rbacConfiguration
      .map((i) => i.permissions)
      .flat()
      .map((i) => ({ name: i.name, id: i.id }));

    return { code: 'ok', data: { roleOwnPermissions, allPermissions } };
  }

  @Post('role/permissions/update')
  async updateRolePermissions(
    @Body() updateRolePermissionsDto: UpdateRolePermissionsDto,
  ) {
    const pattern = { cmd: 'cert.update.role.permissions' };
    const { roleId, permissionIds } = updateRolePermissionsDto;
    const payload = { roleId, permissionIds };
    const result = await firstValueFrom(this.client.send(pattern, payload));
    return { code: 'ok', data: result };
  }

  @Post('user/create')
  async createUser(@Body() createUserDto: CreateUserDto) {
    const pattern = { cmd: 'cert.user.create' };
    const payload = createUserDto;
    const result = await firstValueFrom(this.client.send(pattern, payload));
    return { code: 'ok', data: result };
  }

  @Get('user/find/all')
  async userSelect() {
    const pattern = { cmd: 'cert.find.all.user' };
    const payload = [];
    const result = await firstValueFrom(this.client.send(pattern, payload));
    return { code: 'ok', data: result };
  }

  @Post('user/update')
  async userUpdate(@Body() user: UpdateUserDto) {
    const pattern = { cmd: 'cert.user.update' };
    const payload = user;
    const result = await firstValueFrom(this.client.send(pattern, payload));
    // 删除token
    await firstValueFrom(
      this.client.send({ cmd: 'cert.token.deprecated' }, payload),
    );
    return { code: 'ok', data: result };
  }

  @Post('user/delete')
  async userDelete(@Body() userIds: number[]) {
    const pattern = { cmd: 'cert.user.delete' };
    const payload = userIds;
    const result = await firstValueFrom(this.client.send(pattern, payload));
    return { code: 'ok', data: result };
  }
}
