import { ClientsModule, Transport } from '@nestjs/microservices';
import { NacosModule } from './nacos/nacos.module';
import { AppController } from './app.controller';
import { ConfigModule } from '@nestjs/config';
import { AppService } from './app.service';
import {
  MiddlewareConsumer,
  Module,
  NestModule,
  OnModuleInit,
} from '@nestjs/common';
import { TraceIdMiddleware } from './middleware/trace.middleware';
import { AdminModule } from './admin/admin.module';

@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      envFilePath: `.env.${process.env.NODE_ENV}`,
    }),
    ClientsModule.register([
      {
        name: 'Client',
        transport: Transport.NATS,
        options: {
          servers: ['nats://localhost:4222'],
          maxReconnectAttempts: 5,
          reconnectTimeWait: 1000,
        },
      },
    ]),
    NacosModule,
    AdminModule,
  ],
  controllers: [AppController],
  providers: [AppService],
})
export class AppModule implements NestModule, OnModuleInit {
  constructor(private readonly appService: AppService) {}

  configure(consumer: MiddlewareConsumer) {
    consumer.apply(TraceIdMiddleware).forRoutes('*');
  }

  async onModuleInit() {
    await this.appService.roleInitialization();
    await this.appService.permissionResourceInitialization();
  }
}
