import {
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Series } from './series';
import { ArchiveTask } from './archiveTask';

@Entity()
export class Study {
  @PrimaryGeneratedColumn()
  id: number;

  @Column()
  StudyInstanceUID: string;

  @Column()
  PatientID: string | number;

  @Column()
  PatientName: string;

  @Column()
  PatientSex: string;

  @Column()
  PatientAge: string;

  @CreateDateColumn({ type: 'timestamp' })
  createTime: Date;

  @UpdateDateColumn({ type: 'timestamp' })
  updateTime: Date;

  @OneToMany(() => Series, (series) => series.study)
  series: Series[];

  @ManyToOne(() => ArchiveTask, (archiveTask) => archiveTask.studies)
  @JoinColumn({ name: 'ArchiveTaskId', referencedColumnName: 'id' }) // 自定义连接列
  archiveTask: ArchiveTask;
}
