import { Body, Controller, Inject, Post, Req, Res } from '@nestjs/common';
import { ClientProxy } from '@nestjs/microservices';
import { UserLoginDto } from './auth.dto';
import { firstValueFrom } from 'rxjs';
import { Response, Request } from 'express';

@Controller('auth')
export class AuthController {
  constructor(@Inject('Client') private readonly client: ClientProxy) {}

  @Post('signIn')
  async auth(
    @Req() request: Request,
    @Body() userLoginDto: UserLoginDto,
    @Res({ passthrough: true }) res: Response,
  ) {
    const { username, password } = userLoginDto;
    const { isLegal, data, msg } = await firstValueFrom(
      this.client.send({ cmd: 'cert.user.account' }, { username, password }),
    );
    // 日志
    await firstValueFrom(
      this.client.send(
        { cmd: 'logger.user.signIn' },
        {
          platform: 'dmp',
          username,
          finger: request.headers['x-finger'] as string,
          finger2: request.headers['x-finger2'] as string,
          isLegal,
        },
      ),
    );
    if (isLegal) {
      // 签发token,签用户的角色,前端UI路由鉴权
      const { roles } = data;
      const { token } = await firstValueFrom(
        this.client.send({ cmd: 'cert.token.create' }, { username, roles }),
      );
      const { tokenKeyInCookie, expires } = await firstValueFrom(
        this.client.send({ cmd: 'cert.token.config' }, []),
      );
      res.cookie(tokenKeyInCookie, token, {
        maxAge: expires * 1000,
        httpOnly: true,
      });
      const { password, ...rest } = data;
      return { code: 0, data: rest, msg: '登陆成功' };
    } else {
      return { code: 1, msg };
    }
  }
}
