import { AxiosInstance, Method } from "axios";
import { useEffect, useState } from "react";

interface IProps {
  url: string;
  method?: Extract<Method, keyof AxiosInstance>;
  requestConfig?: any;
  axiosInstance: AxiosInstance;
}

export function useAxios(props: IProps) {
  const { axiosInstance, url, method = "get", requestConfig = {} } = props;
  // 创建一个取消源
  const [data, setData] = useState<any>();
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState<unknown>();

  useEffect(() => {
    const controller = new AbortController();

    const fetchData = async () => {
      try {
        const response = await axiosInstance[method](url, {
          ...requestConfig,
          signal: controller.signal,
        });
        setData(response.data);
      } catch (error) {
        setError(error);
      } finally {
        setLoading(false);
      }
    };

    if (url) fetchData();
    return () => controller.abort();
  }, [axiosInstance, method, url]);

  return { data, error, loading };
}
