import i18n from "i18next";
import { initReactI18next, useTranslation } from "react-i18next";
import LanguageDetector from "i18next-browser-languagedetector";
import Backend from "i18next-http-backend";

interface i18nProps {
  /**
   * 读取i18n translation.json的文件根目录，打包后，翻译json指向 dist/locales
   * @default /locales/{{lng}}/{{ns}}.json
   */
  loadPath?: string;
  /**
   * 如果用户语言翻译无效，默认使用的语言
   * @default zhCN
   */
  fallbackLng?: string;
  /**
   * 是否控制台输出i18n信息
   * @default false
   */
  debug?: boolean;
}

export const useI18n = (p?: i18nProps) => {
  const {
    loadPath = "/locales/{{lng}}/{{ns}}.json",
    fallbackLng = "zhCN",
    debug = false,
  } = p;
  i18n
    .use(Backend)
    // 检测用户当前使用的语言
    // 文档: https://github.com/i18next/i18next-browser-languageDetector
    .use(LanguageDetector)
    // 注入 react-i18next 实例
    .use(initReactI18next)
    // 初始化 i18next
    // 配置参数的文档: https://www.i18next.com/overview/configuration-options
    .init({
      debug, // 控制台输出信息
      fallbackLng, // 如果用户语言的翻译不可用，请使用的语言。
      interpolation: { escapeValue: false },
      backend: { loadPath },
    });
  return { i18n };
};

export { useTranslation };
