import * as CryptoJS from "crypto-js";
import { parse, stringify } from "flatted";

export class SymmetricCrypto {
  private key: string;

  constructor(key?: string) {
    this.key = key ?? "x-finger2";
  }

  encrypt(data: Record<string, string>): string {
    const flattedData = stringify(data);
    return CryptoJS.AES.encrypt(flattedData, this.key).toString();
  }

  decrypt(encryptedData: string): object | null {
    try {
      const bytes = CryptoJS.AES.decrypt(encryptedData, this.key);
      const decryptedData = bytes.toString(CryptoJS.enc.Utf8);
      return parse(decryptedData);
    } catch (error) {
      console.error("Decryption failed:", error);
      return null;
    }
  }
}
