interface SDK_INIT_TYPE {
  app_id: string;
  tracking_attr?: string;
}

declare global {
  interface Window {
    sdk_logger: SDK_Logger;
  }
}

export class SDK_Logger {
  app_id: string;
  tracking_attr: string;
  constructor(p: SDK_INIT_TYPE) {
    this.app_id = p.app_id;
    this.tracking_attr = p?.tracking_attr ?? "data-tracking-id";
    this.initialize();
  }

  initialize() {
    console.log(`SDK_Logger init successfully, using appid: ${this.app_id}`);
  }

  /**
   * 事件冒泡查找点击元素的trackingId
   * @param {HTMLElement} target 被查找的目标元素
   * @param {number} maxLevels 最大向上查找的层级
   * @returns
   */
  findTrackingId(target: HTMLElement | null, maxLevels = 5) {
    const { tracking_attr } = this;
    let t = target;
    while (t && maxLevels-- && !t.hasAttribute(tracking_attr))
      t = t.parentElement;
    return t && t.hasAttribute(tracking_attr)
      ? t.getAttribute(tracking_attr)
      : "";
  }
}
